@@ -12,7 +12,8 @@ WindowContext FirebaseGetWindowContext()
 #elif defined(__ANDROID__)
 #include <unistd.h>
 #include <jni.h>
-#include "SDL.h"
+extern "C" void* SDL_AndroidGetJNIEnv();
+extern "C" void* SDL_AndroidGetActivity();
 
 JNIEnv *FirebaseGetJniEnv()
 {
@@ -96,4 +97,4 @@ bool Firebase::isReady()
 void Firebase::update()
 {
     m_taskQueue.dispatch_main_handler();
-}
\ No newline at end of file
+}
