@@ -1,5 +1,6 @@
 #include "igeFirebase.h"
 #include "igeFirebase_doc_en.h"
+#include "taskflow/taskflow.hpp"
 
 namespace firebase
 {
@@ -72,7 +73,30 @@ PyObject* firebase_str(firebase_obj* self)
 
 static PyObject* firebase_Init(firebase_obj* self, PyObject* args, PyObject* kwargs)
 {
-	const char* kwlist[] = { "analytics", "messaging", "remoteConfig", "firestore", NULL };
+    tf::Executor executor;
+    tf::Taskflow tf;
+
+
+    LOG("---Start----");
+
+    auto [A, B, C, D] = tf.emplace(
+                                   [] () {
+        LOG("Task A");
+        
+    },    //  task dependency graph
+                                   [] () { LOG("Task B");},    //  task dependency graph
+                                   [] () { LOG("Task C");},    //  task dependency graph
+                                   [] () { LOG("Task D");}    //  task dependency graph
+    );                                                    //    |     +---+     |
+    A.precede(B);  // A runs before B                     //  | A |           | D |
+    A.precede(C);  // A runs before C                     //  +---+           +-^-+
+    B.precede(D);  // B runs before D                     //    |     +---+     |
+    C.precede(D);  // C runs before D                     //    +---->| C |-----+
+                                                          //          +---+
+    executor.run(tf).wait();
+
+    
+    const char* kwlist[] = { "analytics", "messaging", "remoteConfig", "firestore", NULL };
 	
 	int analytics = 1;
 	int messaging = 1;
